# Generated by Django 3.0.13 on 2021-03-20 18:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('watermarker', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='watermark',
            name='image',
            field=models.ImageField(upload_to='watermarks', verbose_name='image'),
        ),
        migrations.AlterField(
            model_name='watermark',
            name='is_active',
            field=models.BooleanField(blank=True, default=True, verbose_name='is active'),
        ),
    ]
